package jeu;

/**
 * L'interface <code>IOPlateau</code> est destinée à être implantée
 * (<code>implement</code>) par toutes les interfaces de jeu de plateau.
 * Elle est volontairement très minialiste: il n'y a qu'une méthodes:
 * 
 * la fonction <code>getCoup</code> qui affiche le tableau avant de demander
 * une case au  joueur de désigner une case.
 *
 * @author Pierre.Courtieu at univ-orleans.fr
 * @author Jeremy.Briffaut at ensi-bourges.fr
 * @version 1.0
 */
public interface IOPlateau {

    /**
     * {@code iop.getCoup(s)} affiche le plateau (ou met à jour son affichage)
     * représenté par le
     * tableau de pièces du plateau {@code iop} et attend que l'utilsateur
     * désigne une case.  La chaîne {@code s} est le message de
     * demande affiché pour l'utilisateur. La méthode retourne le numéro
     * de la case sélectionnée (appel bloquant jusqu'à la sélection).
     * Le tableau doit avoir autant de pièces qu'il y a de cases
     * sur le plateau, utiliser la pièce vide pour les cases vides.
     *
     * @param s le message de demande affiché pour l'utilisateur
     * @return Le numéro de la case désignée par le joueur
     * @throws NullPointerException si une case du tableau est {@code null}.
     * Cette exception est une {@code RunTimeException} donc il n'est pas
     * nécessaire de déclarer cette exception dans les annotations {@code throws}.
     */
    public Coordonnees getCoup(String s);

}
